@@ -2,12 +2,11 @@
 
 Mine data fast
 """
-from . import web, internal
-
+from . import web
 
 __all__ = ["web"]
 
-__version__ = "0.1.0"
+__version__ = "0.4.0"
 # For parallism, use that library numpy and friends use
 
 
